#ifdef __cplusplus
extern "C" { 
#endif  

#include "f2c.h" 

int stbsv_(char *uplo, char *trans, char *diag, integer *n, integer *k, real *a, integer *lda, real *x, integer *incx);

#ifdef __cplusplus
}
#endif